@@ -1,9 +1,9 @@
-__version__ = '0.3.2'
+__version__ = '0.4'
 
 try:
     from mando.core import Program
-except ImportError as e:  # unfortunately this is the only workaround for argparse
-                          # and Python 2.6
+except ImportError as e:  # pragma: no cover
+    # unfortunately the only workaround for Python2.6, argparse and setup.py
     e.version = __version__
     raise e
 
